/* Copyright (C) 1996 Bjoern Beutel. */

/* Description. =============================================================*/

/* This module contains options that can be set by both malaga and mallex. */

/* Variables. ===============================================================*/

extern bool_t auto_variables; /* TRUE if variables are shown automatically. */

extern bool_t use_display; 
/* TRUE if "variables" and "result" use the display process. */

/* Commands. ================================================================*/

extern command_t sort_records_option;
/* Select the order in which attributes in a record are printed. */

extern command_t hidden_option;
/* Select which attributes to hide when printing values. */

extern command_t use_display_option;
/* Determine if output is shown using Display process. */

extern command_t auto_variables_option; 
/* Determine if variables are shown automatically in debug mode. */

extern command_t switch_option;
/* Set switches that can be read from Malaga rules. */

extern command_t roman_hangul_option; /* Select latin Hangul transcription. */

/* End of file. =============================================================*/
